@@ -4,6 +4,8 @@
 #include "config.h"
 #endif
 
+#include <locale.h>
+
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
 #include "pygtk-private.h"
@@ -51,7 +53,7 @@ init_gtk(void)
 	    argc = 0;
 	    argv = NULL;
     }
-	
+
     if (!gtk_init_check(&argc, &argv)) {
 	if (argv != NULL) {
 	    for (i = 0; i < argc; i++)
@@ -59,8 +61,14 @@ init_gtk(void)
 	    g_free(argv);
 	}
 	PyErr_SetString(PyExc_RuntimeError, "could not open display");
+	/* set the LC_NUMERIC locale back to "C", as Python requires
+	 * that it be set that way. */
+	setlocale(LC_NUMERIC, "C");
 	return;
     }
+    /* set the LC_NUMERIC locale back to "C", as Python requires that
+     * it be set that way. */
+    setlocale(LC_NUMERIC, "C");
     if (argv != NULL) {
 	PySys_SetArgv(argc, argv);
 	for (i = 0; i < argc; i++)
